summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--drivers/base/dma-buf.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/base/dma-buf.c b/drivers/base/dma-buf.c
index b5d796076ce..fa42c56b30d 100644
--- a/drivers/base/dma-buf.c
+++ b/drivers/base/dma-buf.c
@@ -113,11 +113,11 @@ static unsigned int dma_buf_poll(struct file *filp,
}
/*
* There is no anyone accessing this buffer so just return.
*/
if (!robj->locked) {
mutex_unlock(&robj->lock);
- return POLLIN | POLLOUT;
+ return POLLERR;
}
poll_wait(filp, &robj->poll_wait, poll);
@@ -113,11 +113,11 @@ static unsigned int dma_buf_poll(struct file *filp,
}
/*
- * There is no anyone accessing this buffer so just return.
+ * There is no anyone accessing this buffer so just return POLLERR.
*/
if (!robj->locked) {